summaryrefslogtreecommitdiffstats
path: root/kaddressbook/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kaddressbook/main.cpp')
-rw-r--r--kaddressbook/main.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kaddressbook/main.cpp b/kaddressbook/main.cpp
index 2c88e89b8..e272783e5 100644
--- a/kaddressbook/main.cpp
+++ b/kaddressbook/main.cpp
@@ -33,14 +33,14 @@
#include <kdebug.h>
#include <tdelocale.h>
#include <tdestartupinfo.h>
-#include <kuniqueapplication.h>
+#include <tdeuniqueapplication.h>
#include <twin.h>
#include "kaddressbookmain.h"
#include "kaddressbook_options.h"
#include "kabcore.h"
-class KAddressBookApp : public KUniqueApplication {
+class KAddressBookApp : public TDEUniqueApplication {
public:
KAddressBookApp() : mMainWin( 0 ), mDefaultIsOpen( false ) {}
~KAddressBookApp() {}
@@ -95,7 +95,7 @@ int KAddressBookApp::newInstance()
}
// Handle startup notification and window activation
// We do it ourselves instead of calling KUniqueApplication::newInstance
// to avoid the show() call there.
#if defined TQ_WS_X11 && ! defined K_WS_TQTONLY
static bool firstInstance = true;
@@ -115,7 +115,7 @@ int main( int argc, char *argv[] )
TDECmdLineArgs::init( argc, argv, KABCore::createAboutData() );
TDECmdLineArgs::addCmdLineOptions( kaddressbook_options );
- KUniqueApplication::addCmdLineOptions();
+ TDEUniqueApplication::addCmdLineOptions();
if ( !KAddressBookApp::start() )
return 0;
@@ -95,7 +95,7 @@ int KAddressBookApp::newInstance()
}
// Handle startup notification and window activation
- // We do it ourselves instead of calling KUniqueApplication::newInstance
+ // We do it ourselves instead of calling TDEUniqueApplication::newInstance
// to avoid the show() call there.
#if defined TQ_WS_X11 && ! defined K_WS_TQTONLY